#
# spec file for package openscap
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 8
%define with_bindings 0

Name:           openscap
Version:        1.2.5
Release:        4.5
Source:         https://fedorahosted.org/releases/o/p/openscap/%name-%version.tar.gz
Source5:        https://fedorahosted.org/releases/o/p/openscap/%name-%version.tar.gz.sha1sum
Source1:        oscap-scan.init
Source2:        sysconfig.oscap-scan
# SUSE specific profile, based on yast2-security
# checks.
# Generated from http://gitorious.org/test-suite/scap
Source3:        scap-yast2sec-xccdf.xml
Source4:        scap-yast2sec-oval.xml
Patch0:         fix-missing-include.dif
Url:            http://www.open-scap.org/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libacl-devel
BuildRequires:  libcurl-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libxml2-devel
# Use package name cause of "have choice for perl(XML::Parser): brp-check-suse perl-XML-Parser"
BuildRequires:  gconf2-devel
BuildRequires:  libblkid-devel
BuildRequires:  libcap-devel
BuildRequires:  libselinux-devel
BuildRequires:  libxslt-devel
BuildRequires:  openldap2-devel
BuildRequires:  pcre-devel
BuildRequires:  perl-XML-Parser
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  rpm-devel
BuildRequires:  swig
BuildRequires:  unixODBC-devel
Summary:        A Set of Libraries for Integration with SCAP
License:        LGPL-2.1+
Group:          Development/Tools/Other

%description
OpenSCAP is a set of open source libraries providing an easier path for
integration of the SCAP line of standards.

SCAP is a line of standards managed by NIST with the goal of providing
a standard language for the expression of Computer Network Defense
related information.

More information about SCAP can be found at nvd.nist.gov.


%package -n libopenscap%{soname}
Summary:        OpenSCAP C Library
Group:          System/Libraries

%description -n libopenscap%{soname}
The OpenSCAP C Library for easy integration with SCAP.


%package devel
Requires:       %{name} = %{version}-%{release}
Requires:       libopenscap%{soname} = %{version}
Summary:        Development Files for OpenSCAP
Group:          Development/Libraries/C and C++

%description devel
This package contains the development files (mainly C header files) for the 
OpenSCAP C library.

%if 0%{?with_bindings}
%package -n python-openscap
%py_requires
Requires:       %{name} = %{version}-%{release}
Provides:       openscap-python = %{version}-%{release}
Summary:        OpenSCAP Python Library
Group:          Development/Libraries/Python

%description -n python-openscap
The OpenSCAP Python Library for easy integration with SCAP.

%package -n perl-openscap
Requires:       %{name} = %{version}-%{release}
Requires:       perl = %{perl_version}
Provides:       openscap-perl = %{version}-%{release}
Summary:        OpenSCAP Perl Library
Group:          Development/Libraries/Perl

%description -n perl-openscap
The OpenSCAP Perl Library for easy integration with SCAP.
%endif

%package        utils
Summary:        Openscap utilities
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}
PreReq:         %insserv_prereq %fillup_prereq

%description    utils
The %{name}-utils package contains various utilities based on %{name} library.


%package        content
Summary:        SCAP content
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}

%description    content
SCAP content for Fedora delivered by Open-SCAP project.


%package        extra-probes
Summary:        SCAP probes
Group:          System/Monitoring
Requires:       %{name} = %{version}-%{release}
#BuildRequires:  opendbx - for sql

%description    extra-probes
The %{name}-extra-probes package contains additional probes that are not
commonly used and require additional dependencies.

%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

%prep
%setup -q
%patch0 -p1 

%build

%if 0%{?with_bindings}
%configure --disable-silent-rules
%else
%configure --disable-silent-rules --disable-bindings --disable-python
%endif
%__make %{?_smp_mflags}

%check
# #%__make check %{?_smp_mflags} ||:

%install
%__make install DESTDIR=%{buildroot}
find %{buildroot} -name "*.la" -delete

mkdir -p $RPM_BUILD_ROOT/var/adm/fillup-templates
install -d -m 755 $RPM_BUILD_ROOT%{_initrddir}
install -p -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{_initrddir}/oscap-scan
install -m 644 %{SOURCE2} $RPM_BUILD_ROOT/var/adm/fillup-templates

install -m 644 %{SOURCE3}  $RPM_BUILD_ROOT/%{_datadir}/openscap
install -m 644 %{SOURCE4}  $RPM_BUILD_ROOT/%{_datadir}/openscap

# create symlinks to default content
ln -s  %{_datadir}/openscap/scap-yast2sec-oval.xml $RPM_BUILD_ROOT/%{_datadir}/openscap/scap-oval.xml
ln -s  %{_datadir}/openscap/scap-yast2sec-xccdf.xml $RPM_BUILD_ROOT/%{_datadir}/openscap/scap-xccdf.xml

%post -n libopenscap%{soname} -p /sbin/ldconfig

%postun -n libopenscap%{soname} -p /sbin/ldconfig

%preun utils
%{stop_on_removal oscap-scan}

%post utils
%{fillup_and_insserv -n oscap-scan}

%postun utils
%{restart_on_update oscap-scan}
%{insserv_cleanup}

%files
%defattr(-, root, root)
%doc AUTHORS COPYING ChangeLog NEWS 
%dir %{_libexecdir}/openscap
%{_libexecdir}/openscap/probe_dnscache
%{_libexecdir}/openscap/probe_environmentvariable
%{_libexecdir}/openscap/probe_environmentvariable58
%{_libexecdir}/openscap/probe_family
%{_libexecdir}/openscap/probe_file
%{_libexecdir}/openscap/probe_fileextendedattribute
%{_libexecdir}/openscap/probe_filehash
%{_libexecdir}/openscap/probe_filehash58
%{_libexecdir}/openscap/probe_iflisteners
%{_libexecdir}/openscap/probe_inetlisteningservers
%{_libexecdir}/openscap/probe_interface
%{_libexecdir}/openscap/probe_partition
%{_libexecdir}/openscap/probe_password
%{_libexecdir}/openscap/probe_process
%{_libexecdir}/openscap/probe_process58
%{_libexecdir}/openscap/probe_routingtable
%{_libexecdir}/openscap/probe_rpminfo
%{_libexecdir}/openscap/probe_rpmverify*
%{_libexecdir}/openscap/probe_runlevel
%{_libexecdir}/openscap/probe_selinuxboolean
%{_libexecdir}/openscap/probe_selinuxsecuritycontext
%{_libexecdir}/openscap/probe_shadow
%{_libexecdir}/openscap/probe_symlink
%{_libexecdir}/openscap/probe_sysctl
%{_libexecdir}/openscap/probe_systemdunitdependency
%{_libexecdir}/openscap/probe_systemdunitproperty
%{_libexecdir}/openscap/probe_system_info
%{_libexecdir}/openscap/probe_textfilecontent
%{_libexecdir}/openscap/probe_textfilecontent54
%{_libexecdir}/openscap/probe_uname
%{_libexecdir}/openscap/probe_variable
%{_libexecdir}/openscap/probe_xinetd
%{_libexecdir}/openscap/probe_xmlfilecontent

%dir %{_datadir}/openscap
%dir %{_datadir}/openscap/cpe
%dir %{_datadir}/openscap/schemas
%dir %{_datadir}/openscap/xsl
%{_datadir}/openscap/cpe/*
%{_datadir}/openscap/schemas/*
%{_datadir}/openscap/xsl/*

%files -n libopenscap%{soname}
%defattr(-, root, root)
%{_libdir}/libopenscap.so.%{soname}*

%files devel
%defattr(-, root, root)
%doc docs/{html,examples}/
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%if 0%{?with_bindings}
%files -n python-openscap
%defattr(-, root, root)
%{python_sitearch}/*

%files -n perl-openscap
%defattr(-, root, root)
%{perl_vendorlib}/openscap.pm
%{perl_vendorarch}/_openscap_pm.so
%endif

%files utils
%defattr(-,root,root,-)
/var/adm/fillup-templates/sysconfig.oscap-scan
%doc docs/oscap-scan.cron
%{_initrddir}/oscap-scan
%{_mandir}/man8/*
%{_bindir}/*
%config %{_sysconfdir}/bash_completion.d/*

%files content
%defattr(-,root,root,-)
%{_datadir}/openscap/scap*.xml

%files extra-probes
%defattr(-,root,root,-)
%{_libexecdir}/openscap/probe_ldap57
%{_libexecdir}/openscap/probe_gconf

%changelog
* Mon Jul  6 2015 meissner@suse.com
- openscap-1.2.5 update
  - maintenance
  - smaller bugfixes
  - plugged memory leaks
  - fixed fresh static analysis (coverity) findings
  - fixed shellcheck warnings
  - fixes for Solaris platform
* Mon Jun 22 2015 meissner@suse.com
- openscap-1.2.4 update
  - new features
  - OVAL 5.11 support 99.8%% completed!
  - new symlink probe introduced
  - new process58 test capabilities
  - added possible_value support for external variables
  - added possible_restriction support for external variables
  - improved IP address comparisons
  - Added Scientific Linux CPEs
  - Added oscap-docker tool
  - Created man-page for oscap-ssh
  - HTML changes
  - improved visibility of selected XCCDF profile in guides and reports
  - render rule-result/message contents in reports
  - maintenance
  - Tests now pass on ppc64 little endian arch (rhbz#1215220)
  - partition probe now supports remount, bind and move mount options
  - Patched NIST OVAL-5.11 schemas to be backward compatible with
    OVAL-5.10 (rhbz#1220262)
  - fixed scap-as-rpm to work with vintage python (2.6)
  - better error reporting when a probe dies (i.e. due to OOM killer)
  - dropped selinux policy from upstream (rhbz#1209969)
  - fix segfault on invalid selectors (rhbz#1220944)
  - solaris support patches: file-system zones, systeminfo improvements
  - many smaller fixes and new tests
* Sun May  3 2015 meissner@suse.com
- openscap-1.2.3 update
  - new features
  - oscap-ssh -- handy utility to run remote scan over ssh
  - glob_to_regexp OVAL function added
  - HTML changes
  - show rationale elements
  - show fixtext elements
  - show Benchmark's front-matter, description and notices
  - show warnings for Groups and Rules
  - improved handling of multiple fixes within a single Rule
  - scroll evaluation characteristic if they overflow
  - maintenance
  - OVAL 5.11 schema fixes
  - Coverity and memory leak fixes
  - skip transient files when traversing /proc (trac#457)
* Tue Apr  7 2015 meissner@suse.com
- openscap-1.2.2 update
  - new features
  - OVAL 5.11 support turned on by default
  - included OVAL 5.11 schematron rules
  - DataStream can now contain OVAL 5.11
  - `oscap ds sds-compose` now supports --skip-valid parameter
  - HTML report changes
  - Notably increased level of OVAL details
  - Table of contents is now generated for HTML guides
  - maitenance
  - rhbz#1182242, rhbz#1159289 - @var_check & @var_ref exporting
  - solaris build fixes
  - xccdf:fix/instance processing fixes
  - improved (none) epoch processing in rpm probe
  - environmentvariable58 now emits warning messages when appropriate
  - offline mode improvements
  - other bugfixes
* Mon Jan 12 2015 meissner@suse.com
- openscap-1.2.1 update
  - API changes
  - 5.11 schemas updated (from RC1 to gold)
  - oscap_source_new_from_memory can take bzip2ed content
  - HTML report changes
  - severity bar is now reversed (left-to-right)
  - maintenance
  - rhbz#1165139 - fix probe cancelation
  - dozen of bugfixes
* Tue Dec  2 2014 meissner@suse.com
- openscap-1.2.0 update
  - new features
  - native support of bzip2ed SCAP files (file extension needs to be '.xml.bz2')
  - improved performance on huge XML documents, especially DataStreams
  - minimized use of temp files to absolute minimum
  - added OVAL-5.11 release candidate schemas
  - API changes
  - overall 50 new symbols added to public API
  - introduced oscap_source abstraction for input files
  - further info: http://isimluk.livejournal.com/4859.html
  - all the parsers converted to use oscap_source abstraction
  - introduced ds_sds_session, high level API for playing with Source DataStreams
  - introduced cpe_session, abstraction to approach multiple CPE resources
  - introduced ds_rds_session, high level API for playing with Result DataStreams
    (ARF files)
  - deprecated dozens of API calls dependent on filepath
  - introduced API for waivers (xccdf:override) and modification of ARF
  - initial support for waivers in HTML Report
  - dozens of small improvements
  - maintenance
  - dozens of small fixes
  - dozens of memory leaks (whole test suite is now leak free)
  - updated gnulib
- openscap-1.1.0-fix-bashisms.patch: upstreamed
* Mon Dec  1 2014 meissner@suse.com
- openscap-1.1.1 update
  - Hint towards `oscap info` when profile is not found in oscap tool
  - HTML report changes:
  - Source OVAL results from ARF if available
  - Highlight notchecked rules, treat them as rules that need attention
  - HTML guide changes:
  - Variable Substitution improvements
  - Show benchmark title
  - Show info about selected profile
  - Avoid cdf12:notice, show only its contents
  - bugfixes:
  - improved handling of fqdn in XCCDF
  - memory leaks
  - static analysis fixes
* Sat Nov 29 2014 Led <ledest@gmail.com>
- fix bashism in oscap-scan.cron script
- add patches:
  * openscap-1.1.0-fix-bashisms.patch
* Wed Sep  3 2014 meissner@suse.com
- openscap-1.1.0 update
  - HTML report and guide redesign
  - dropped support for docbook
  - Introduced new probes (that are to be part of OVAL 5.11)
  - probe_systemdunitproperty
  - probe_systemdunitdependency
  - introduced raw bindings for python3
  - dozens of small bug fixes
* Wed Jul  2 2014 meissner@suse.com
- openscap-1.0.9 update
  - xccdf_session_export_arf must not return 0 if the export failed
  - expose xccdf_policy_get_value_of_item as public API
  - skip "Signature" when parsing sds_index without spewing out an error
  - return non-zero when cannot resolve XCCDF
  - consider the last set-value as the effective set-value and export only one
  - test suite fixes
  - do not destroy SVG data in XCCDFs when generating guide or report
* Thu Jun 19 2014 crrodriguez@opensuse.org
- Remove unused build require on libnl-1_1 according to the
  changelog, it stopped beign used in 2010
- libattr is also unused.
* Fri Mar 28 2014 meissner@suse.com
- openscap-1.0.8 update:
  - fixes related to Asset Reporting Format
  - Inject arf:report/@id into nested
    rule-result/check/check-content-ref/@href
  - Add hostname for each fqdn when generating ARF asset identification
    data
  - Add all MAC addresses from target-facts to ARF as asset
    identification data
* Fri Mar 21 2014 meissner@suse.com
- openscap-1.0.7 update:
  - fix namespaces for attributes in ARF relationship element
  - Avoid ".00" as the score in HTML report when score is 0.
* Wed Mar 19 2014 meissner@suse.com
- openscap-1.0.6 update:
  - fix process58 loginuid integer handling on 32bit
* Mon Mar 17 2014 meissner@suse.com
- openscap-1.0.5 update:
  - XCCDF titles and description support xccdf:sub resolution
  - HTML Report lists only applicable cpe platforms
  - TestResult element contains applicable cpe platforms
  - Introduced XCCDF 1.2 schematron validation
  - XCCDF bug fixes
  - tailoring profiles shall regards inherited refine-values (trac#373)
  - rule-result now always includes at least one check
  - Other bug fixes:
  - Dpkginfo probe collects epoch in evr
  - Updated examplary openscap-content based on the latest facts from
    Red Hat Enterprise Linux 6
  - Minor changes
* Fri Feb 14 2014 meissner@suse.com
- openscap-1.0.4 update:
  - Introduced xccdf_tailoring_remove_profile to API
  - OVAL bug fixes
* Tue Jan 14 2014 meissner@suse.com
- openscap-1.0.3 update:
  - bug fixes
  - a few coverity issues
  - a few memory leak plugs
  - broken comparison of huge integet in OVAL
- fix-return.patch: removed, has upstream fix
* Fri Jan 10 2014 meissner@suse.com
- openscap-1.0.2 update:
  - XCCDF generate fix now supports tailoring file
  - XCCDF bug fixes
  - Generate guide points to RHSA pages (rhbz#1018291)
  - Generate report ommits remediation when assesment passed
    (rhbz#1029879)
  - $PATH variable is available for SCE checks (rhbz#1026833)
  - Tailoring of top-level Group elements via API fixed
  - Fix-filtering should not drop fixes (affected SSG)
  - Generated fix file is created with sane permissions (trac#362)
  - Inherit parent's namespace when exporting oscap_text with HTML
    trait
  - OVAL bug fixes:
  - Handful of xinetd probe fixes
  - Handful of process and process58 fixes
  - Obsoleted textfilecontent now supports text ent comparisons
  - rpm*_item/epoch is reported as '(none)' when needed
  - Fixed dozen of flaws in ipv4 and ipv6_address comparison
    (CIDR handling)
  - Made integer and floating type number parsing much stricter
  - Fixed floating point numbers comparisons (trac#366)
  - Fixed case-insensitive comparisons
  - Item filtering fixes in probes
  - Consolidated some of comparisons in results model and probes
    (trac#367)
  - Other bug fixes:
  - Workaround libxml2 bug handling x509 xmldsig (gnomebz#350248)
  - Fixed static build (--disable-shared)
  - Format assertions (-Werror=format-security) turned on by default
  - SCE scripts are notified when parent (oscap) is killed
  - oscap info now recognizes all the document types
    (adeded: tailoring & CVE)
  - Documentation improvements
  - Handful of other minor fixes
- fix-return.patch: Fixed a void return
* Mon Dec  2 2013 meissner@suse.com
- move the gconf probe to openscap-extra-probes to reduce
  dependencies of the core probe set.
* Thu Nov 28 2013 meissner@suse.com
- openscap-1.0.1 update:
  - versioned interface is used to handle internal SCE plug-in
  - build-in gnulib package was updated to current version
  - bug fixes:
  - selinux_domain_label and posix_capability properties
    were reintroduced to OVAL system characteristics model
  - selinux_domain_label now collects the domain/type
    (not the context)
  - oscap oval collect reports progress on stdout (not on the stderr)
  - typo in the manual page (rhbz#1032537), and another small
    clarification
* Tue Nov 19 2013 meissner@suse.com
- openscap-1.0.0 / 19-11-2013
  - Improved heuristic to distinguish 'local' and 'remote' file systems
  - Improved comparison of EntityStateEVRStringType (trac#355)
  - Link against librpm (if available) to include rpmvercmp
    (on other platforms we fall back to the build-in rpmvercmp)
  - Bug fixes
- openscap-0.9.13 / 08-11-2013
  - Moved SCE to separate shared library (libopenscap_sce.so)
  - Introduction of scap-as-rpm tool
  - Improvements of sql and sql57 probes
  - Improvements of SELinux policy
  - Amendments based on SCAP 1.2 Errata (sp800-126r2-errata-20120409.pdf)
  - Minor improvements in state_entity processing
  - Introduction of CPE name for Fedora 21 to the internal dictionary
  - Added support for ind-def:pid/@xsi:nil (rhbz#1013011)
  - Improved error reporting
  - Bug fixes
  - Changed CPE name regex to be more permissive
  - avoided reports from the library to the stdout and stderr
  - plugged several memory leaks
  - improved xccdf:check-content-refs processing
  - misspelling in syslog message (rhbz#1021695)
  - fixed OVAL's <field> element processing
  - fixes based on static analysers
  - test suite is locale independent
- new library major version 8
* Fri Oct 11 2013 meissner@suse.com
- Updated to 0.9.12
  - tailoring improvements (@id, version, and benchmark ref attributes)
  - XCCDF 1.1 tailoring extension
  - improved robustness of CPE dictionary parser and exporter
  - and added misc CPE 2.3 elements
  - added Fedora 20 to internal CPE dictionary
  - updated OVAL's results_to_html stylesheet from Mitre Corporation.
  - profiles with duplicate selects (same @idref) now export correctly
  - test improvements
  - bug fixes
  - fixed IPv6 export in TestResult/target-address
  - consistently inject target-id-ref into TestResult in ARFs
  - improved rpmdb manipulation (rhbz#999903)
  - solaris build fixes
  - spelling of name of default language fixed (oscap_text related)
  - fixed CPE names matching (generalization vs. specialization)
* Wed Jul 17 2013 meissner@suse.com
- Updated to 0.9.11
  - bugfixes
- Updated to 0.9.10
  - bugfixes
- Updated to 0.9.9
  - --oval-results also exports CPE OVAL results
  - added --benchmark-id to select a component-ref by ID of Benchmark it's pointing to
  - OVAL variable_instance processing (or so called value multiset) and the processing
    of @variable_instance attribute to OVAL Result Definition, OVAL Result Test and
    Collected Objects.
  - improved test coverage of OVAL variable processing
  - introduced new internal data type: oval_smc
  - added support for evaluating OVAL definitions against an RPM database, a.k.a. rpm
    database offline mode
  - bug fixes and dead code removal
* Mon Jun 17 2013 meissner@suse.com
- updated to 0.9.8
  - added experimental support for offline mode scanning to the OVAL
    check engine (i.e. scanning of virtual host disk images)
  - improved OVAL variables processing
  - bug fixes and dead code removal
* Sat May  4 2013 mc@suse.com
- fix build on SLE11 - possible 64Bit issue
  - fix-missing-include.dif
* Mon Apr 29 2013 meissner@suse.com
- updated to 0.9.7
  - bugfixes
* Thu Apr 25 2013 meissner@suse.com
- updated to 0.9.6
  - new command-line module added as preview: "oscap ds sds-add"
  - improved xccdf:fix processing (support of DataStreams and CPE)
  - internal selinux policy preview
  - added Fedora 19 to default CPE dictionary
  - bug fixes
* Wed Mar 20 2013 meissner@suse.com
- updated to 0.9.5
  - oscap xccdf remediate (new oscap module which introduces offline
    remediation; the remediation based on existing xccdf:testresult file)
  - added support for sce into datastream (sce scripts can now be
    embedded into the datastream file similarly as oval can)
  - improved bash completion and documentation
  - bug fixes
- bumped SOVERSION from 2 to 3.
* Wed Feb 27 2013 meissner@suse.com
- updated to 0.9.4
  - high Level API
  - improved Text Substitution Processing
  - technical Preview of Online Remediation Execution
    (the oscap xccdf eval --remediate)
  - improved Library Internal Error Reporting.
  - the oscap xccd export-oval-variables now support DataStreams.
  - improved documentation
  - improved schema files.
  - tailoring file support
  - profile shadowing support
  - bug Fixes
- DOWNGRADED SOVERSION from 3 to 2.
* Tue Jan  8 2013 meissner@suse.com
- updated to 0.9.3
  - Embedded CPE dictionary (allows users to ommit --cpe argument)
  - improvements of DataStream and CPE processing on RHEL5
  - changed API of various functions in cpe_dict, benchmark and
    xccdf_policy to use string timestamp instead of time_t [1]
  - fixed several issues found by Coverity and cppcheck static code
    analysis
  - bug fixes
- bumped SOVERSION from 2 to 3.
* Mon Nov 19 2012 meissner@suse.com
- updated to 0.9.2:
- rewritten the heuristic for pattern matching on path and filepath
- CPE 2.3 language applicability testing
- new ds_sds_index API providing a datastream overview
- CPEs in source datastreams are automatically registered and used
  for XCCDF evaluation
- --cpe option autodetects CPE dictionary and language
- CVE support (validate feed, print CVEs)
- introduced info module
- made "$oscap xccdf generate custom" work again -> man page update
- bug fixes
* Thu Oct 25 2012 meissner@suse.com
- updated to 0.9.1:
  - the http in the check-content-ref/@hrefhref support
  - the cpedict support
  - obsoleted the oscap_reporter
  - send start and finish messages to the syslog
  - the XCCDF multi-check evaluation support
  - "oscap oval validate-xml" autodetect a document type
  - bug fixes
* Fri Sep 28 2012 meissner@suse.com
- updated to 0.9.0:
  * few public headers were renamed to follow common schema
  * cve and cce modules are not build by default -> these modules are not
    utilized by oscap tool and thus untested.
  * --enable-bindings configure option was split into --enable-python and
    support of SCAP datastream support was improved
  * plus fixes in OVAL and XCCDF modules. oscap tool reports support of
    XCCDF 1.2 and OVAL 5.10.1
- libopenscap.so major version changed from 1 to 2.
* Wed Aug 29 2012 meissner@suse.com
- updated to 0.8.5:
  - added rpmverifypackage probe
  - added initial support for source and result datastreams
  - added xccdf 1.2 dc-status support
  - several probes were updated to conform to OVAL 5.10.1
  - bug fixes
  This release is able to evaluate the DISA STIG content.
* Tue Aug  7 2012 meissner@suse.com
- updated to 0.8.4
  - added OVAL schemas 5.9, 5.10.1
  - alloc.h is no more public api
  - bug fixes
* Fri Aug  3 2012 dmacvicar@suse.de
- Fix schema_version of scap-rhel6-oval.xml (to 5.8)
* Wed Aug  1 2012 meissner@suse.com
- Updated to 0.8.3
  - added XCCDF 1.2 schemas
  - changed XCCDF report format
  - updated schemas for OVAL 5.10
  - added additional OVAL schemas - 5.3, 5.4, 5.5, 5.6, 5.7
  - multi version support for XCCDF and OVAL
  - a schema version of an imported and exported content is same
  - added rpmverifyfile probe
  - results are validated only if an OSCAP_FULL_VALIDATION variable is set
  - bug fixes
* Wed Aug  1 2012 dmacvicar@suse.de
- add OVAL/XCCDF content based on yast2-security checks
  and set them as the default content (using symlinks)
* Sat Jul 28 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Fri Mar 30 2012 meissner@suse.de
- Updated to 0.8.2
  - XCCDF check-import support
  - XSLT transformation for XCCDF 1.1 to 1.2 migration
  - SCE reports now optionally use the new check-import functionality
    and don't need separate SCE result files
  - bug fixes
* Sat Mar 24 2012 mc@suse.com
- require libnl-devel on older SUSE version
* Mon Mar 19 2012 cfarrell@suse.com
- license update: LGPL-2.1+
  There is no GPL-3.0+ in this package. Also, the Fedora spec file states
  LGPL-2.1+. This appears to be the correct license
* Wed Feb 29 2012 meissner@suse.de
- some cleanups to make it factory acceptable
* Tue Feb 28 2012 mc@suse.de
- Update to 0.8.1
- introduce Script Check Engine
- Added an OVAL Directives schema to allow for a tool
  to supply a set of directives to more easily specify
  desired results content.
- Enhanced OVAL Results directives to allow for more flexibility
  in allowed results content
- added new OVAL objects(all OVAL 5.8 objects are covered now)
- update dpkgprobe
- all issues reported by coverity are fixed
- add capability to export OVAL Variables from XCCDF
- added cvss score calculator from vector
* Fri Apr 29 2011 meissner@suse.de
- Updated to 0.7.2
  - OVAL 5.7 is supported
  - content for Red Hat Enterprise Linux 6.1 - draft
  - oscap tool enable user to skip content validation before evaluation
  - bugfixes
* Mon Jul  5 2010 bitshuffler #suse@irc.freenode.org
- Update to 0.5.12
- Proper subpackages added
* Thu Nov 19 2009 meissner@suse.de
- initial 0.5.5 import
  - open SCAP protocol implementation
